@@ -17,7 +17,7 @@
 
 #include "kmoretoolspresets.h"
 #include "kmoretoolspresets_p.h"
-
+#include "knewstuff_debug.h"
 #include <QDebug>
 #include <QHash>
 
@@ -28,7 +28,7 @@
 class KmtServiceInfo
 {
 public:
-    KmtServiceInfo(QString desktopEntryName, QString homepageUrl, int maxUrlArgCount)
+    KmtServiceInfo(const QString &desktopEntryName, const QString &homepageUrl, int maxUrlArgCount)
         : desktopEntryName(desktopEntryName), homepageUrl(homepageUrl), maxUrlArgCount(maxUrlArgCount)
     {
     }
@@ -48,14 +48,21 @@ KMoreToolsService* KMoreToolsPresets::registerServiceByDesktopEntryName(KMoreToo
 #define ADD_ENTRY(desktopEntryName, maxUrlArgCount, homepageUrl) dict.insert(desktopEntryName, KmtServiceInfo(desktopEntryName, QLatin1String(homepageUrl), maxUrlArgCount));
 
     //
-    // definitions begin:
+    // definitions begin (sorted alphabetically):
     //                                              .------ If one gives more URL arguments as
     //                                              |       specified here the program will not work.
     //                                              |       Note, that there are some desktop files where _too few_
     //                                              |       arguments also lead to errors. Watch the console
     //                                              v       output for messages from the program.
     //
+    ADD_ENTRY("angrysearch",                        0, "https://github.com/DoTheEvo/ANGRYsearch");
+    ADD_ENTRY("com.uploadedlobster.peek",           0, "https://github.com/phw/peek"); // easy to use screen recorder, creates gif
     ADD_ENTRY("catfish",                            1, "http://www.twotoasts.de/index.php/catfish/");
+    ADD_ENTRY("ding",                               0, "https://www-user.tu-chemnitz.de/~fri/ding/"); // Offline dict, Online: http://dict.tu-chemnitz.de/dings.cgi
+    ADD_ENTRY("disk",                               0, "https://en.opensuse.org/YaST_Disk_Controller");
+    ADD_ENTRY("fontinst",                           0, "https://docs.kde.org/trunk5/en/kde-workspace/kcontrol/fontinst/"); // good for previewing many fonts at once
+    ADD_ENTRY("fontmatrix",                         0, "https://github.com/fontmatrix/fontmatrix");
+    ADD_ENTRY("fsearch",                            0, "http://www.fsearch.org/");
     ADD_ENTRY("giggle",                             1, "https://wiki.gnome.org/Apps/giggle/"); // good for searching in history
     ADD_ENTRY("git-cola-folder-handler",            1, "https://git-cola.github.io");
     ADD_ENTRY("git-cola-view-history.kmt-edition",  1, "https://git-cola.github.io");
@@ -63,23 +70,27 @@ KMoreToolsService* KMoreToolsPresets::registerServiceByDesktopEntryName(KMoreToo
     ADD_ENTRY("qgit.kmt-edition",                   1, "http://libre.tibirna.org/projects/qgit");
     ADD_ENTRY("gitg",                               1, "https://wiki.gnome.org/action/show/Apps/Gitg?action=show&redirect=Gitg");
     ADD_ENTRY("gnome-search-tool",                  0, "https://help.gnome.org/users/gnome-search-tool/"); // has good filtering options
+    ADD_ENTRY("gucharmap",                          0, "https://wiki.gnome.org/action/show/Apps/Gucharmap");
     ADD_ENTRY("gparted",                            0, "http://gparted.org");
     ADD_ENTRY("htop",                               0, "http://hisham.hm/htop/");
-    ADD_ENTRY("org.kde.PartitionManager",           0, "https://www.kde.org/applications/system/kdepartitionmanager/");
-    ADD_ENTRY("disk",                               0, "https://en.opensuse.org/YaST_Disk_Controller");
-    ADD_ENTRY("kdf",                                0, "https://www.kde.org/applications/system/kdiskfree");
-    ADD_ENTRY("ksystemlog",                         0, "https://www.kde.org/applications/system/ksystemlog/");
-    ADD_ENTRY("org.gnome.clocks",                   0, "https://wiki.gnome.org/Apps/Clocks");
-    ADD_ENTRY("org.kde.filelight",                  1, "https://utils.kde.org/projects/filelight");
-    ADD_ENTRY("org.kde.kfind",                      1, "https://www.kde.org/applications/utilities/kfind/"); // has good filtering options
-    ADD_ENTRY("org.kde.plasma.cuttlefish.kmt-edition", 0, "http://vizzzion.org/blog/2015/02/say-hi-to-cuttlefish/");
-    ADD_ENTRY("org.kde.ksysguard",                  0, "https://userbase.kde.org/KSysGuard");
-    ADD_ENTRY("org.kde.ktimer",                     0, "https://www.kde.org/applications/utilities/ktimer/");
     ADD_ENTRY("hotshots",                           1, "http://sourceforge.net/projects/hotshots/");
     ADD_ENTRY("kaption",                            0, "http://kde-apps.org/content/show.php/?content=139302");
-    ADD_ENTRY("org.kde.kscreengenie",               0, "http://quickgit.kde.org/?p=kscreengenie.git");
-    ADD_ENTRY("org.kde.ksnapshot",                  0, "https://www.kde.org/applications/graphics/ksnapshot/");
-    ADD_ENTRY("shutter",                            0, "http://shutter-project.org");
+    ADD_ENTRY("kding",                              0, ""); // Offline dict; unmaintained?
+    ADD_ENTRY("org.kde.kmousetool",                 0, "https://www.kde.org/applications/utilities/kmousetool/");
+    ADD_ENTRY("org.gnome.clocks",                   0, "https://wiki.gnome.org/Apps/Clocks");
+    ADD_ENTRY("org.kde.filelight",                  1, "https://utils.kde.org/projects/filelight");
+    ADD_ENTRY("org.kde.kcharselect",                0, "https://utils.kde.org/projects/kcharselect/");
+    ADD_ENTRY("org.kde.kdf",                        0, "https://www.kde.org/applications/system/kdiskfree");
+    ADD_ENTRY("org.kde.kfind",                      1, "https://www.kde.org/applications/utilities/kfind/"); // has good filtering options
+    ADD_ENTRY("org.kde.partitionmanager",           0, "https://www.kde.org/applications/system/kdepartitionmanager/");
+    ADD_ENTRY("org.kde.plasma.cuttlefish.kmt-edition", 0, "http://vizzzion.org/blog/2015/02/say-hi-to-cuttlefish/");
+    ADD_ENTRY("org.kde.ksysguard",                  0, "https://userbase.kde.org/KSysGuard");
+    ADD_ENTRY("org.kde.ksystemlog",                 0, "https://www.kde.org/applications/system/ksystemlog/");
+    ADD_ENTRY("org.kde.ktimer",                     0, "https://www.kde.org/applications/utilities/ktimer/");
+    ADD_ENTRY("org.kde.spectacle",                  0, "https://www.kde.org/applications/graphics/spectacle");
+    ADD_ENTRY("simplescreenrecorder",               0, "http://www.maartenbaert.be/simplescreenrecorder/");
+    ADD_ENTRY("shutter",                            0, "http://shutter-project.org"); // good for edit screenshot after capture
+    ADD_ENTRY("vokoscreen",                         0, "https://github.com/vkohaupt/vokoscreen"); // feature-rich screen recorder
     ADD_ENTRY("xfce4-taskmanager",                  0, "http://goodies.xfce.org/projects/applications/xfce4-taskmanager");
     //
     // ...definitions end
@@ -100,7 +111,7 @@ KMoreToolsService* KMoreToolsPresets::registerServiceByDesktopEntryName(KMoreToo
         }
         return service;
     } else {
-        qDebug() << "KMoreToolsPresets::registerServiceByDesktopEntryName: " << desktopEntryName << "was not found. Return nullptr.";
+        qCDebug(KNEWSTUFF) << "KMoreToolsPresets::registerServiceByDesktopEntryName: " << desktopEntryName << "was not found. Return nullptr.";
         return nullptr;
     }
 }
@@ -127,22 +138,26 @@ QList<KMoreToolsService*> KMoreToolsPresetsPrivate::registerServicesByGroupingNa
     // For special handlings about naming in the menu etc. see kmoretoolsmenufactory.cpp/addItemsForGroupingNameWithSpecialHandling
 
     //
-    // definitions begin:
+    // grouping definitions begin (sorted alphabetically):
     //
-    dict.insert(_("disk-usage"), { _("kdf"), _("org.kde.filelight") });
-    dict.insert(_("disk-partitions"), { _("gparted"), _("org.kde.PartitionManager"), _("disk") });
-    dict.insert(_("files-find"), { _("org.kde.kfind"), _("more:"), _("gnome-search-tool"), _("catfish") });
+    dict.insert(_("disk-usage"), { _("org.kde.kdf"), _("org.kde.filelight") });
+    dict.insert(_("disk-partitions"), { _("gparted"), _("org.kde.partitionmanager"), _("disk") });
+    dict.insert(_("files-find"), { _("org.kde.kfind"), _("fsearch"), _("more:"), _("gnome-search-tool"), _("catfish"), _("angrysearch") });
+    dict.insert(_("font-tools"), { _("fontinst"), _("gucharmap"), _("more:"), _("org.kde.kcharselect"), _("fontmatrix") });
     dict.insert(_("git-clients-for-folder"), { _("git-cola-folder-handler"), _("gitk.kmt-edition"),
                 _("giggle"), _("qgit.kmt-edition"), _("gitg") });
     dict.insert(_("git-clients-and-actions"), { _("git-cola-folder-handler"), _("git-cola-view-history.kmt-edition"),
                 _("giggle"), _("gitk.kmt-edition"), _("qgit.kmt-edition"), _("gitg") });
     dict.insert(_("icon-browser"), { _("org.kde.plasma.cuttlefish.kmt-edition") });
-    dict.insert(_("screenshot-take"), { _("org.kde.ksnapshot"), _("org.kde.kscreengenie"), _("shutter"), _("kaption"), _("hotshots") });
+    dict.insert(_("language-dictionary"), { _("ding"), _("kding") });
+    dict.insert(_("mouse-tools"), { _("org.kde.kmousetool") }); // todo: add program "xbanish" to remove mouse cursor while typing
+    dict.insert(_("screenrecorder"), { _("com.uploadedlobster.peek"), _("simplescreenrecorder"), _("vokoscreen") });
+    dict.insert(_("screenshot-take"), { _("org.kde.spectacle"), _("shutter"), _("kaption"), _("hotshots") });
     dict.insert(_("system-monitor-processes"), { _("org.kde.ksysguard"), _("more:"), _("htop"), _("xfce4-taskmanager") });
-    dict.insert(_("system-monitor-logs"), { _("ksystemlog") });
+    dict.insert(_("system-monitor-logs"), { _("org.kde.ksystemlog") });
     dict.insert(_("time-countdown"), { _("org.gnome.clocks"), _("org.kde.ktimer") });
     //
-    // ...definitions end
+    // ...grouping definitions end
     //
 
     QList<KMoreToolsService*> resultList;
