@@ -20,6 +20,7 @@
 
 #include "uploaddialog.h"
 #include "uploaddialog_p.h"
+#include "ui/widgetquestionlistener.h"
 
 #include <QDialogButtonBox>
 #include <QFileDialog>
@@ -28,10 +29,11 @@
 #include <QLayout>
 #include <QDoubleSpinBox>
 #include <QPointer>
-#include <QtCore/QString>
-#include <QtCore/QSignalMapper>
+#include <QString>
+#include <QSignalMapper>
 #include <QCoreApplication>
 
+#include <kiconloader.h>
 #include <kmessagebox.h>
 #include <klocalizedstring.h>
 
@@ -76,7 +78,7 @@ bool UploadDialogPrivate::init(const QString &configfile)
     buttonBox->setStandardButtons(QDialogButtonBox::Cancel);
     layout->addWidget(buttonBox);
 
-    atticaHelper = new AtticaHelper(q);
+    atticaHelper = new KNSCore::AtticaHelper(q);
 
     bool success = true;
     KConfig conf(configfile);
@@ -143,12 +145,14 @@ bool UploadDialogPrivate::init(const QString &configfile)
 
     //Busy widget
     busyWidget = new KPixmapSequenceWidget();
-    busyWidget->setSequence(KPixmapSequence(QStringLiteral("process-working"), 22));
+    busyWidget->setSequence(KIconLoader::global()->loadPixmapSequence(QStringLiteral("process-working"), 22));
     busyWidget->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
     ui.busyWidget->setLayout(new QHBoxLayout());
     ui.busyWidget->layout()->addWidget(busyWidget);
     busyWidget->setVisible(false);
 
+    WidgetQuestionListener::instance();
+
     return success;
 }
 
@@ -285,7 +289,7 @@ void UploadDialogPrivate::_k_providerChanged(const QString &providerName)
     atticaHelper->setCurrentProvider(providerName);
     QString registerUrl = atticaHelper->provider().getRegisterAccountUrl();
     if (! registerUrl.isEmpty()) {
-        ui.registerNewAccountLabel->setText("<a href=\"register\">" + i18n("Register a new account") + "</a>");
+        ui.registerNewAccountLabel->setText(QStringLiteral("<a href=\"register\">") + i18n("Register a new account") + QStringLiteral("</a>"));
     } else {
         ui.registerNewAccountLabel->setText(QString());
     }
@@ -422,7 +426,7 @@ UploadDialog::UploadDialog(QWidget *parent)
     : QDialog(parent), d(new UploadDialogPrivate(this))
 {
     const QString name = QCoreApplication::applicationName();
-    init(name + ".knsrc");
+    init(name + QStringLiteral(".knsrc"));
 }
 
 UploadDialog::UploadDialog(const QString &configFile, QWidget *parent)
@@ -455,7 +459,7 @@ bool UploadDialog::init(const QString &configfile)
 
     connect(d->backButton, SIGNAL(clicked()), this, SLOT(_k_backPage()));
     connect(d->nextButton, SIGNAL(clicked()), this, SLOT(_k_nextPage()));
-    connect(d->buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(d->buttonBox, &QDialogButtonBox::accepted, this, &UploadDialog::accept);
     connect(d->buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
     QString displayName = QGuiApplication::applicationDisplayName();
@@ -752,7 +756,7 @@ void UploadDialogPrivate::_k_contentAdded(Attica::BaseJob *baseJob)
 
 void UploadDialogPrivate::_k_openRegisterAccountWebpage(QString)
 {
-    KRun::runUrl(QUrl::fromUserInput(atticaHelper->provider().getRegisterAccountUrl()), QStringLiteral("text/html"), q);
+    KRun::runUrl(QUrl::fromUserInput(atticaHelper->provider().getRegisterAccountUrl()), QStringLiteral("text/html"), q, KRun::RunFlags());
 }
 
 void UploadDialogPrivate::doUpload(const QString &index, const QUrl &path)
@@ -770,7 +774,7 @@ void UploadDialogPrivate::doUpload(const QString &index, const QUrl &path)
 
     QString fileName = QFileInfo(path.toLocalFile()).fileName();
 
-    Attica::PostJob *job = 0;
+    Attica::PostJob *job = nullptr;
     if (index.isEmpty()) {
         job = currentProvider().setDownloadFile(contentId, fileName, fileContents);
         q->connect(job, SIGNAL(finished(Attica::BaseJob*)), q, SLOT(_k_fileUploadFinished(Attica::BaseJob*)));
